Items class

Constructors

Items({String? description, String? name, UnitPrice? unitPrice, int? quantity, UnitPrice? total, String? details})
Items.fromJson(Map<String, dynamic> json)

Properties

description ↔ String?
getter/setter pair
details ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
getter/setter pair
quantity ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
total ↔ UnitPrice?
getter/setter pair
unitPrice ↔ UnitPrice?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited