Payer class

Constructors

Payer({String? userId, Email? email, Name? name, List<Addresses>? addresses, List<Phones>? phones})
Payer.fromJson(Map<String, dynamic> json)

Properties

addresses ↔ List<Addresses>?
getter/setter pair
email ↔ Email?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imageUrl ↔ String?
getter/setter pair
name ↔ Name?
getter/setter pair
phones ↔ List<Phones>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited