FPayPalErrorInfo class

Inheritance

Constructors

FPayPalErrorInfo()

Properties

error ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
map → Map<String, dynamic>
returns a non null map
no setterinherited
nativeSdkVersion ↔ String
getter/setter pair
orderId ↔ String
getter/setter pair
reason ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromJson(Map<String, dynamic> data) → FPayPalErrorInfo
getInt(dynamic name, {int defaultVal = 0}) → int
inherited
getList(dynamic name, {List? defaultVal}) → List?
inherited
getMap(dynamic name, {Map<String, dynamic>? defaultVal}) → Map<String, dynamic>?
inherited
getMapList(dynamic name, {List<Map<String, dynamic>>? defaultVal}) → List<Map<String, dynamic>>?
inherited
getString(dynamic name, {String defaultVal = ""}) → String
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setMap(Map<String, dynamic> mapV) → void
set a non null map
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited