MapHelper class

Implementers

Constructors

MapHelper()

Properties

hashCode → int
The hash code for this object.
no setterinherited
map → Map<String, dynamic>
returns a non null map
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getInt(dynamic name, {int defaultVal = 0}) → int
getList(dynamic name, {List? defaultVal}) → List?
getMap(dynamic name, {Map<String, dynamic>? defaultVal}) → Map<String, dynamic>?
getMapList(dynamic name, {List<Map<String, dynamic>>? defaultVal}) → List<Map<String, dynamic>>?
getString(dynamic name, {String defaultVal = ""}) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setMap(Map<String, dynamic> mapV) → void
set a non null map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited